California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 025 - REFERENDUM TO OVERTURN A 2018 LAW THAT REPLACED MONEY BAIL SYSTEM WITH A SYSTEM BASED ON PUBLIC SAFETY RISK. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1428656 | VOTE NO ON PROPOSITION 25 - CITIZENS FOR EQUAL JUSTICE FOR ALL - SPONSORED BY DMCG, INC. AND FC&S INSURANCE AGNECY | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1417278 | CALIFORNIANS FOR BAIL REFORM | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1410088 | NO ON PROP 25 - STOP THE UNFAIR, UNSAFE AND COSTLY BALLOT PROPOSITION, SPONSORED BY THE AMERICAN BAIL COALITION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1432577 | NO ON PROP 25 - COMMITTEE AGAINST PRETRIAL RACISM | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1434061 | NORTH BAY BAIL AGENTS ASSOCIATION AGAINST PROPOSITION 25 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1422734 | YES ON PROP 25, A COALITION OF JUSTICE REFORM AND LABOR ORGANIZATIONS | SUPPORT